# -*- coding: utf-8 -*-
"""Define project metadata
"""

__package_name__ = 'sugar.py'
__description__ = 'Python utility library. Based on sugar Javascript Library.'
__url__ = 'https://github.com/bharadwajyarlagadda/sugar.py'
__version__ = '0.1.1'
__author__ = 'Bharadwaj Yarlagadda'
__email__ = 'yarlagaddabharadwaj@gmail.com'
__license__ = 'MIT License'
